==> webkit2gtk_2.48.7.orig.tar.xz: webkitgtk-2.48.7/Source/WebCore/platform/graphics/texmap/coordinated/GraphicsLayerAsyncContentsDisplayDelegateCoordinated.h <==
/*
 * Copyright (C) 2024, 2025 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if USE(COORDINATED_GRAPHICS)
#include "GraphicsLayerContentsDisplayDelegate.h"

namespace WebCore {

class GraphicsLayer;

class GraphicsLayerAsyncContentsDisplayDelegateCoordinated final : public GraphicsLayerAsyncContentsDisplayDelegate {
public:
    static Ref<GraphicsLayerAsyncContentsDisplayDelegateCoordinated> create(GraphicsLayer& layer)
    {
        return adoptRef(*new GraphicsLayerAsyncContentsDisplayDelegateCoordinated(layer));
    }
    virtual ~GraphicsLayerAsyncContentsDisplayDelegateCoordinated();

    void updateGraphicsLayer(GraphicsLayer&);

private:
    explicit GraphicsLayerAsyncContentsDisplayDelegateCoordinated(GraphicsLayer&);

    void setDisplayBuffer(std::unique_ptr<CoordinatedPlatformLayerBuffer>&&) override { RELEASE_ASSERT_NOT_REACHED(); }
    bool display(CoordinatedPlatformLayer&) override { RELEASE_ASSERT_NOT_REACHED(); }

    bool tryCopyToLayer(ImageBuffer&) override;

    Ref<GraphicsLayerContentsDisplayDelegate> m_delegate;
};

} // namespace WebCore

#endif // USE(COORDINATED_GRAPHICS)

==> webkit2gtk_2.50.0.orig.tar.xz: webkitgtk-2.50.0/Source/WebCore/platform/graphics/texmap/coordinated/GraphicsLayerAsyncContentsDisplayDelegateCoordinated.h <==
/*
 * Copyright (C) 2024, 2025 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if USE(COORDINATED_GRAPHICS)
#include "GraphicsLayerContentsDisplayDelegate.h"

namespace WebCore {

class GraphicsLayer;

class GraphicsLayerAsyncContentsDisplayDelegateCoordinated final : public GraphicsLayerAsyncContentsDisplayDelegate {
public:
    static Ref<GraphicsLayerAsyncContentsDisplayDelegateCoordinated> create(GraphicsLayer& layer)
    {
        return adoptRef(*new GraphicsLayerAsyncContentsDisplayDelegateCoordinated(layer));
    }
    virtual ~GraphicsLayerAsyncContentsDisplayDelegateCoordinated();

    void updateGraphicsLayer(GraphicsLayer&);

private:
    explicit GraphicsLayerAsyncContentsDisplayDelegateCoordinated(GraphicsLayer&);

    void setDisplayBuffer(std::unique_ptr<CoordinatedPlatformLayerBuffer>&&) override { RELEASE_ASSERT_NOT_REACHED(); }
    bool display(CoordinatedPlatformLayer&) override { RELEASE_ASSERT_NOT_REACHED(); }

    bool tryCopyToLayer(ImageBuffer&, bool opaque) override;

    const Ref<GraphicsLayerContentsDisplayDelegate> m_delegate;
};

} // namespace WebCore

#endif // USE(COORDINATED_GRAPHICS)
